@@ -179,21 +179,13 @@ class Exif(object):
 
     @property
     def thumbnail(self):
-        compression = self._unpack('H', self._get_tag_offset(0x103)+8)
-        if compression != 6:
-            raise ValueError("Image does not contain a JPEG thumbnail")
         offset = (self._exif_start +
                   self._unpack('I', self._get_tag_offset(0x201)+8))
         size = self._unpack('I', self._get_tag_offset(0x202)+8)
+        if self._buf[:2] != b'\xff\xd8':
+            raise ValueError("Thumbnail is not in JPEG format.")
         return self._buf[offset:offset+size]
 
-    @thumbnail.setter
-    def thumbnail(self, data):
-        offset, old_size = self._thumbnail_offset()
-        # TODO: Write thumbdata into imgdata
-        # TODO: Update size, move following data
-        raise NotImplementedError
-
     def _get_tag_offset(self, tagnum):
         # IFD0 pointer starts after alignment (2 bytes) and tag mark (2 bytes)
         p_ifd = self._unpack('I', self._exif_start+4)+self._exif_start
@@ -203,14 +195,15 @@ class Exif(object):
             idx = p_ifd + 2
             for _ in range(num_entries):
                 tag_num = self._unpack('H', idx)
-                # Check if we're at the orientation tag
+                # Check if we're at the desired tag
                 if tag_num == tagnum:
                     return idx
                 idx += 12
-            p_ifd = self._unpack('I', idx)+self._exif_start
-            if not p_ifd:
+            p_ifd = self._unpack('I', idx)
+            if p_ifd == 0:  # This means there are no more IFDs
                 raise ExifTagNotFound("Could not find EXIF Tag {0}"
                                       .format(tagnum))
+            p_ifd += self._exif_start
 
     def _thumbnail_offset(self):
         # Number of entries is 2 bytes, each entry is 12 bytes
